@@ -23,7 +23,7 @@ Usage::
     list_predictors_paginator: ListPredictorsPaginator = client.get_paginator("list_predictors")
 """
 # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
-from typing import Generator, List, TYPE_CHECKING
+from typing import Iterator, List, TYPE_CHECKING
 from botocore.paginate import Paginator as Boto3Paginator
 from mypy_boto3_forecast.type_defs import (
     FilterTypeDef,
@@ -49,77 +49,77 @@ __all__ = (
 
 class ListDatasetGroupsPaginator(Boto3Paginator):
     """
-    [Paginator.ListDatasetGroups documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.12/reference/services/forecast.html#ForecastService.Paginator.ListDatasetGroups)
+    [Paginator.ListDatasetGroups documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.17/reference/services/forecast.html#ForecastService.Paginator.ListDatasetGroups)
     """
 
     def paginate(
         self, PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Generator[ListDatasetGroupsResponseTypeDef, None, None]:
+    ) -> Iterator[ListDatasetGroupsResponseTypeDef]:
         """
-        [ListDatasetGroups.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.12/reference/services/forecast.html#ForecastService.Paginator.ListDatasetGroups.paginate)
+        [ListDatasetGroups.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.17/reference/services/forecast.html#ForecastService.Paginator.ListDatasetGroups.paginate)
         """
 
 
 class ListDatasetImportJobsPaginator(Boto3Paginator):
     """
-    [Paginator.ListDatasetImportJobs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.12/reference/services/forecast.html#ForecastService.Paginator.ListDatasetImportJobs)
+    [Paginator.ListDatasetImportJobs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.17/reference/services/forecast.html#ForecastService.Paginator.ListDatasetImportJobs)
     """
 
     def paginate(
         self, Filters: List[FilterTypeDef] = None, PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Generator[ListDatasetImportJobsResponseTypeDef, None, None]:
+    ) -> Iterator[ListDatasetImportJobsResponseTypeDef]:
         """
-        [ListDatasetImportJobs.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.12/reference/services/forecast.html#ForecastService.Paginator.ListDatasetImportJobs.paginate)
+        [ListDatasetImportJobs.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.17/reference/services/forecast.html#ForecastService.Paginator.ListDatasetImportJobs.paginate)
         """
 
 
 class ListDatasetsPaginator(Boto3Paginator):
     """
-    [Paginator.ListDatasets documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.12/reference/services/forecast.html#ForecastService.Paginator.ListDatasets)
+    [Paginator.ListDatasets documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.17/reference/services/forecast.html#ForecastService.Paginator.ListDatasets)
     """
 
     def paginate(
         self, PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Generator[ListDatasetsResponseTypeDef, None, None]:
+    ) -> Iterator[ListDatasetsResponseTypeDef]:
         """
-        [ListDatasets.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.12/reference/services/forecast.html#ForecastService.Paginator.ListDatasets.paginate)
+        [ListDatasets.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.17/reference/services/forecast.html#ForecastService.Paginator.ListDatasets.paginate)
         """
 
 
 class ListForecastExportJobsPaginator(Boto3Paginator):
     """
-    [Paginator.ListForecastExportJobs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.12/reference/services/forecast.html#ForecastService.Paginator.ListForecastExportJobs)
+    [Paginator.ListForecastExportJobs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.17/reference/services/forecast.html#ForecastService.Paginator.ListForecastExportJobs)
     """
 
     def paginate(
         self, Filters: List[FilterTypeDef] = None, PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Generator[ListForecastExportJobsResponseTypeDef, None, None]:
+    ) -> Iterator[ListForecastExportJobsResponseTypeDef]:
         """
-        [ListForecastExportJobs.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.12/reference/services/forecast.html#ForecastService.Paginator.ListForecastExportJobs.paginate)
+        [ListForecastExportJobs.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.17/reference/services/forecast.html#ForecastService.Paginator.ListForecastExportJobs.paginate)
         """
 
 
 class ListForecastsPaginator(Boto3Paginator):
     """
-    [Paginator.ListForecasts documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.12/reference/services/forecast.html#ForecastService.Paginator.ListForecasts)
+    [Paginator.ListForecasts documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.17/reference/services/forecast.html#ForecastService.Paginator.ListForecasts)
     """
 
     def paginate(
         self, Filters: List[FilterTypeDef] = None, PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Generator[ListForecastsResponseTypeDef, None, None]:
+    ) -> Iterator[ListForecastsResponseTypeDef]:
         """
-        [ListForecasts.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.12/reference/services/forecast.html#ForecastService.Paginator.ListForecasts.paginate)
+        [ListForecasts.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.17/reference/services/forecast.html#ForecastService.Paginator.ListForecasts.paginate)
         """
 
 
 class ListPredictorsPaginator(Boto3Paginator):
     """
-    [Paginator.ListPredictors documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.12/reference/services/forecast.html#ForecastService.Paginator.ListPredictors)
+    [Paginator.ListPredictors documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.17/reference/services/forecast.html#ForecastService.Paginator.ListPredictors)
     """
 
     def paginate(
         self, Filters: List[FilterTypeDef] = None, PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Generator[ListPredictorsResponseTypeDef, None, None]:
+    ) -> Iterator[ListPredictorsResponseTypeDef]:
         """
-        [ListPredictors.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.12/reference/services/forecast.html#ForecastService.Paginator.ListPredictors.paginate)
+        [ListPredictors.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.17/reference/services/forecast.html#ForecastService.Paginator.ListPredictors.paginate)
         """
